==> qtjambi-xml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiXml/QXmlLocator_shell.cpp <==
#include "QXmlLocator_shell.h"
#include <QtJambi/Cast>

void deleter_QXmlLocator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlLocator")
    QXmlLocator *_ptr = reinterpret_cast<QXmlLocator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QXmlLocator_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QXmlLocator_shell) ); }

jmethodID QXmlLocator_shell::__shell_javaMethod(int pos) const { return QXmlLocator_shell::__shell()->javaMethod(typeid(QXmlLocator), pos); }

// emitting (writeShellConstructor)
QXmlLocator_shell::QXmlLocator_shell()
    : QXmlLocator()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QXmlLocator::QXmlLocator_shell()", QXmlLocator_shell::__shell())
    QXmlLocator_shell::__shell()->constructed(typeid(QXmlLocator));
}

// emitting (writeShellDestructor)
QXmlLocator_shell::~QXmlLocator_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QXmlLocator::~QXmlLocator()", QXmlLocator_shell::__shell())
    QXmlLocator_shell::__shell()->destructed(typeid(QXmlLocator));
}

void QXmlLocator_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QXmlLocator_shell*>(ptr)->QXmlLocator_shell::__shell()->tryDeleteShell(typeid(QXmlLocator));
}

// emitting Virtual overrides (virtualFunctions)
int QXmlLocator_shell::columnNumber() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QXmlLocator::columnNumber()const", QXmlLocator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            int  __qt_return_value = 0;
            QTJAMBI_TRY {
                if(jobject __java_this = QXmlLocator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jint __java_return_value = __jni_env->CallIntMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<int>(__java_return_value);
                } else {
                    QXmlLocator_shell::__shell()->warnForMethod("QXmlLocator::columnNumber()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QXmlLocator::columnNumber()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return 0;
        }
    }else{
        return 0;
    }
}

int QXmlLocator_shell::lineNumber() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QXmlLocator::lineNumber()const", QXmlLocator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            int  __qt_return_value = 0;
            QTJAMBI_TRY {
                if(jobject __java_this = QXmlLocator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jint __java_return_value = __jni_env->CallIntMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<int>(__java_return_value);
                } else {
                    QXmlLocator_shell::__shell()->warnForMethod("QXmlLocator::lineNumber()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QXmlLocator::lineNumber()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return 0;
        }
    }else{
        return 0;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jint QXmlLocator_access::__qt_columnNumber(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QXmlLocator::columnNumber() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QXmlLocator::columnNumber() const.";
    } else {
        int __qt_return_value = columnNumber();
        return jint(__qt_return_value);
    }
}

jint QXmlLocator_access::__qt_lineNumber(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QXmlLocator::lineNumber() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QXmlLocator::lineNumber() const.";
    } else {
        int __qt_return_value = lineNumber();
        return jint(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QXmlLocator()
void __qt_construct_QXmlLocator_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlLocator()")
    Q_UNUSED(__java_arguments)
    QXmlLocator *__qt_this = new(__qtjambi_ptr) QXmlLocator_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QXmlLocator_shell
void __qt_destruct_QXmlLocator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlLocator")
    reinterpret_cast<QXmlLocator_shell*>(ptr)->~QXmlLocator_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlLocator::QXmlLocator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlLocator_initialize_1native__Lio_qt_xml_QXmlLocator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlLocator::QXmlLocator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlLocator_0, sizeof(QXmlLocator_shell), typeid(QXmlLocator), true, &deleter_QXmlLocator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlLocator::columnNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlLocator_00024ConcreteWrapper_columnNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlLocator *__qt_this = QtJambiAPI::objectFromNativeId<QXmlLocator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlLocator::columnNumber()const", __qt_this)
        __java_return_value = static_cast<const QXmlLocator_access*>(__qt_this)->__qt_columnNumber(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlLocator::lineNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlLocator_00024ConcreteWrapper_lineNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlLocator *__qt_this = QtJambiAPI::objectFromNativeId<QXmlLocator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlLocator::lineNumber()const", __qt_this)
        __java_return_value = static_cast<const QXmlLocator_access*>(__qt_this)->__qt_lineNumber(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QXmlLocator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QXmlLocator>("QXmlLocator", "io/qt/xml/QXmlLocator");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "columnNumber", "()I", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "lineNumber", "()I", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QXmlLocator, {
        ConstructorInfo(&__qt_construct_QXmlLocator_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlLocator);
    registerSizeOfShell(typeId, sizeof(QXmlLocator_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiXml/QXmlLocator_shell.cpp <==
#include "QXmlLocator_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QXmlLocator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlLocator")
    QXmlLocator *_ptr = reinterpret_cast<QXmlLocator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QXmlLocator_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QXmlLocator_shell) ); }

jmethodID QXmlLocator_shell::__shell_javaMethod(int pos) const { return QXmlLocator_shell::__shell()->javaMethod(typeid(QXmlLocator), pos); }

// emitting (writeShellConstructor)
QXmlLocator_shell::QXmlLocator_shell()
    : QXmlLocator()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QXmlLocator::QXmlLocator_shell()", QXmlLocator_shell::__shell())
    QXmlLocator_shell::__shell()->constructed(typeid(QXmlLocator));
}

// emitting (writeShellDestructor)
QXmlLocator_shell::~QXmlLocator_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QXmlLocator::~QXmlLocator()", QXmlLocator_shell::__shell())
    QXmlLocator_shell::__shell()->destructed(typeid(QXmlLocator));
}

void QXmlLocator_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QXmlLocator_shell*>(ptr)->QXmlLocator_shell::__shell()->tryDeleteShell(typeid(QXmlLocator));
}

// emitting Virtual overrides (virtualFunctions)
int QXmlLocator_shell::columnNumber() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QXmlLocator::columnNumber()const", QXmlLocator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            int  __qt_return_value = 0;
            QTJAMBI_TRY {
                if(jobject __java_this = QXmlLocator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jint __java_return_value = __jni_env->CallIntMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<int>(__java_return_value);
                } else {
                    QXmlLocator_shell::__shell()->warnForMethod("QXmlLocator::columnNumber()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QXmlLocator::columnNumber()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return 0;
        }
    }else{
        return 0;
    }
}

int QXmlLocator_shell::lineNumber() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QXmlLocator::lineNumber()const", QXmlLocator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            int  __qt_return_value = 0;
            QTJAMBI_TRY {
                if(jobject __java_this = QXmlLocator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jint __java_return_value = __jni_env->CallIntMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<int>(__java_return_value);
                } else {
                    QXmlLocator_shell::__shell()->warnForMethod("QXmlLocator::lineNumber()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QXmlLocator::lineNumber()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return 0;
        }
    }else{
        return 0;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jint QXmlLocator_access::__qt_columnNumber_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QXmlLocator::columnNumber() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QXmlLocator::columnNumber() const.";
    } else {
        int __qt_return_value = columnNumber();
        return jint(__qt_return_value);
    }
}

jint QXmlLocator_access::__qt_lineNumber_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QXmlLocator::lineNumber() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QXmlLocator::lineNumber() const.";
    } else {
        int __qt_return_value = lineNumber();
        return jint(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QXmlLocator()
void __qt_construct_QXmlLocator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlLocator()")
    Q_UNUSED(__java_arguments)
    QXmlLocator *__qt_this = new(__qtjambi_ptr) QXmlLocator_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QXmlLocator::QXmlLocator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlLocator_initialize_1native__Lio_qt_xml_QXmlLocator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlLocator::QXmlLocator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlLocator, sizeof(QXmlLocator_shell), typeid(QXmlLocator), true, &deleter_QXmlLocator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QXmlLocator_shell
void __qt_destruct_QXmlLocator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlLocator")
    reinterpret_cast<QXmlLocator_shell*>(ptr)->~QXmlLocator_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlLocator::columnNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlLocator_00024ConcreteWrapper_columnNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlLocator *__qt_this = QtJambiAPI::objectFromNativeId<QXmlLocator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlLocator::columnNumber()const", __qt_this)
        __java_return_value = static_cast<const QXmlLocator_access*>(__qt_this)->__qt_columnNumber_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlLocator::lineNumber()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlLocator_00024ConcreteWrapper_lineNumber_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlLocator *__qt_this = QtJambiAPI::objectFromNativeId<QXmlLocator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlLocator::lineNumber()const", __qt_this)
        __java_return_value = static_cast<const QXmlLocator_access*>(__qt_this)->__qt_lineNumber_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QXmlLocator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QXmlLocator>("QXmlLocator", "io/qt/xml/QXmlLocator");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "columnNumber", "()I", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "lineNumber", "()I", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QXmlLocator, {
        ConstructorInfo(&__qt_construct_QXmlLocator, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlLocator);
    registerSizeOfShell(typeId, sizeof(QXmlLocator_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
